package action;

import java.util.List;

import javax.annotation.Resource;

import model.Book;
import model.Category;
import model.Indent;
import model.User;

import org.apache.struts2.convention.annotation.Action;
import org.apache.struts2.convention.annotation.Namespace;
import org.apache.struts2.convention.annotation.Result;
import org.apache.struts2.convention.annotation.Results;

import service.BookService;
import service.CategoryService;
import service.IndentService;
import service.UserService;
import util.PageUtil;

@Namespace("/book")
@Results({
	@Result(name="index",location="/book/index.jsp"),
	@Result(name="about",location="/book/about.jsp"),
	@Result(name="category",location="/book/category.jsp"),
	@Result(name="special",location="/book/special.jsp"),
	@Result(name="new",location="/book/new.jsp"),
	@Result(name="sale",location="/book/sale.jsp"),
	@Result(name="login",location="/book/login.jsp"),
	@Result(name="register",location="/book/register.jsp"),
	@Result(name="detail",location="/book/detail.jsp"),
	@Result(name="right",location="/book/right.jsp"),
	@Result(name="cart",location="/book/cart.jsp"),
})	
public class IndexAction extends BaseAction{
	private static final long serialVersionUID = 1L;

	private Book book;
	private int bookid;
	private int category;
	private int flag;
	
	private List<Book> bookList;
	private List<Book> specialList;
	private List<Book> newList;
	private List<Book> saleList;
	private List<Category> categoryList;
	
	@Resource
	private UserService userService;
	@Resource
	private BookService bookService;
	@Resource
	private IndentService indentService;
	@Resource
	private CategoryService categoryService;
	

	/**
	 * 首页
	 * @return
	 */
	@Action("index")
	public String index(){
		specialList = bookService.getSpecialList(Book.type_special, 1, 2);
		newList = bookService.getSpecialList(Book.type_new, 1, 6);
		flag = 1;
		return "index";
	}
	
	/**
	 * 简介
	 * @return
	 */
	@Action("about")
	public String about(){
		flag = 2;
		return "about";
	}
	
	/**
	 * 精品推荐
	 * @return
	 */
	@Action("special")
	public String special(){
		specialList = bookService.getSpecialList(Book.type_special, page, 3);
		pageTool = PageUtil.getPageTool(servletRequest, bookService.getSpecialTotal(Book.type_special), page, 3);
		flag = 3;
		return "special";
	}
	
	/**
	 * 最新出版
	 * @return
	 */
	@Action("new")
	public String news(){
		newList = bookService.getSpecialList(Book.type_new, page,3);
		pageTool = PageUtil.getPageTool(servletRequest, bookService.getSpecialTotal(Book.type_new), page, 3);
		flag = 4;
		return "new";
	}
	
	/**
	 * 优惠促销
	 * @return
	 */
	@Action("sale")
	public String sale(){
		saleList = bookService.getSpecialList(Book.type_sale, page, 3);
		pageTool = PageUtil.getPageTool(servletRequest, bookService.getSpecialTotal(Book.type_sale), page, 3);
		flag = 5;
		return "sale";
	}
	
	/**
	 * 登录
	 * @return
	 */
	@Action("login")
	public String login(){
		flag = 6;
		return "login";
	}
	
	/**
	 * 注册
	 * @return
	 */
	@Action("register")
	public String register(){
		flag = 7;
		return "register";
	}
	
	/**
	 * 类目搜索
	 * @return
	 */
	@Action("category")
	public String category(){
		bookList = bookService.getCategoryList(category, page, 12);
		pageTool = PageUtil.getPageTool(servletRequest, bookService.getCategoryTotal(category), page, 12);
		return "category";
	}
	
	/**
	 * 详情
	 * @return
	 */
	@Action("detail")
	public String detail(){
		book = bookService.get(bookid);
		return "detail";
	}

	/**
	 * 右侧信息
	 * @return
	 */
	@Action("right")
	public String right(){
		categoryList = categoryService.getList();
		saleList = bookService.getSpecialList(Book.type_sale, 1, 2);
		return "right";
	}
	
	/**
	 * 查看购物车
	 * @return
	 */
	@Action("cart")
	public String cart() {
		if (getSession().get("username")==null) {
			addActionMessage("请登录后查看购物车!");
			return "login";
		}
		return "cart";
	}
	
	/**
	 * 购买
	 * @return
	 */
	@Action("buy")
	public void buy(){
		Object username = getSession().get("username");
		if (username==null || username.toString().isEmpty()) {
			sendResponseMsg("login");
		}else{
			String indentKey = "indent";
			Indent indent = (Indent) getSession().get(indentKey);
			if (indent==null) {
				getSession().put(indentKey, indentService.createIndent(bookService.get(bookid)));
			}else {
				getSession().put(indentKey, indentService.addIndentItem(indent, bookService.get(bookid)));
			}
			sendResponseMsg("ok");
		}
	}
	
	/**
	 * 提交订单
	 * @return
	 */
	@Action("order")
	public String order(){
		String username = getSession().get("username").toString();
		String indentKey = "indent";
		Indent indent = (Indent) getSession().get(indentKey);
		User user = userService.get(username);
		indent.setUser(user);
		indentService.saveIndent(indent);	// 保存订单
		getSession().remove(indentKey);	// 清除购物车
		addActionMessage("提交订单成功!");
		return "cart";
	}

	
	
	public List<Book> getBookList() {
		return bookList;
	}

	public void setBookList(List<Book> bookList) {
		this.bookList = bookList;
	}

	public List<Book> getSpecialList() {
		return specialList;
	}

	public void setSpecialList(List<Book> specialList) {
		this.specialList = specialList;
	}

	public List<Book> getNewList() {
		return newList;
	}

	public void setNewList(List<Book> newList) {
		this.newList = newList;
	}

	public List<Book> getSaleList() {
		return saleList;
	}

	public void setSaleList(List<Book> saleList) {
		this.saleList = saleList;
	}

	public List<Category> getCategoryList() {
		return categoryList;
	}

	public void setCategoryList(List<Category> categoryList) {
		this.categoryList = categoryList;
	}

	public Book getBook() {
		return book;
	}

	public void setBook(Book book) {
		this.book = book;
	}

	public int getBookid() {
		return bookid;
	}

	public void setBookid(int bookid) {
		this.bookid = bookid;
	}

	public int getCategory() {
		return category;
	}

	public void setCategory(int category) {
		this.category = category;
	}

	public int getFlag() {
		return flag;
	}

	public void setFlag(int flag) {
		this.flag = flag;
	}
	
}
