package service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.annotation.Resource;

import model.Book;
import model.Indent;
import model.Items;

import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import dao.IndentDao;

@Service
@Transactional
public class IndentService {

	@Resource
	private IndentDao indentDao;
	
	/**
	 * 创建订单
	 * @param bookid
	 * @return
	 */
	public Indent createIndent(Book book) {
		List<Items> itemList = new ArrayList<>();
		itemList.add(createItems(book));
		Indent indent = new Indent();
		indent.setItemList(itemList);
		indent.setTotal(book.getPrice());
		indent.setAmount(1);
		return indent;
	}
	
	/**
	 * 创建订单项
	 * @param book
	 * @return
	 */
	private Items createItems(Book book) {
		Items item = new Items();
		item.setBook(book);
		item.setAmount(1);
		return item;
	}

	/**
	 * 向订单添加项目
	 * @param indentList
	 * @param bookid
	 * @return
	 */
	public Indent addIndentItem(Indent indent, Book book) {
		List<Items> itemList = indent.getItemList();
		itemList = itemList==null ? new ArrayList<Items>() : itemList;
		// 如果购物车已有此书, 数量+1
		boolean noThisBook = true;
		for (Items item : itemList) {
			if (item.getBook().getId() == book.getId()) {
				item.setAmount(item.getAmount() + 1);
				noThisBook = false;
			}
		}
		// 如果当前购物车没有此书, 创建新条目
		if (noThisBook) {
			itemList.add(createItems(book));
		}
		indent.setTotal(indent.getTotal() + book.getPrice());
		indent.setAmount(indent.getAmount() + 1);
		return indent;
	}

	/**
	 * 保存订单
	 * @param indent
	 */
	public void saveIndent(Indent indent) {
		indent.setStatus(1);
		indent.setSystime(new Date());
		int indentId = indentDao.save(indent);
		for(Items item : indent.getItemList()){
			item.setIndent(indentDao.get(Indent.class, indentId));
			indentDao.save(item);
		}
	}
	
	/**
	 * 获取订单列表
	 * @param page
	 * @param row
	 * @return
	 */
	public List<Indent> getList(int status, int page, int row) {
		return indentDao.getList(status, page, row);
	}
	
	/**
	 * 获取总数
	 * @return
	 */
	public int getTotal(int status) {
		return (int)indentDao.getTotal(status);
	}

	/**
	 * 处理订单
	 * @param id
	 * @return 
	 */
	public boolean dispose(int id) {
		Indent indent = indentDao.get(Indent.class, id);
		indent.setStatus(2);
		return indentDao.update(indent);
	}

	/**
	 * 删除订单
	 * @param id
	 */
	public boolean delete(int id) {
		Indent indent = new Indent();
		indent.setId(id);
		return indentDao.delete(indent);
	}

	/**
	 * 订单项列表
	 * @param indentid
	 * @param page
	 * @param rows
	 * @return
	 */
	public List<Items> getItemList(int indentid, int page, int rows) {
		return indentDao.getItemList(indentid, page, rows);
	}
	
	/**
	 * 订单项总数
	 * @return
	 */
	public int getItemTotal(int status) {
		return (int)indentDao.getItemTotal(status);
	}
	
}
